@@ -15,12 +15,18 @@ struct _task {
 	__u16 t_errno; /* Last error */
 };
 
+#define TASK_RUNNING 0x1
+#define TASK_STOPPED 0x2
+#define TASK_UNINTER 0x4
+
 /* We use typedefs to avoid using struct foobar (*) */
 typedef struct _task __task;
 typedef struct _task * __ptask;
 
 __task task[MAX_TASKS];
 
+extern __ptask CURRENT, NEXT;
+
 _FUNCTION(__uint build_task, ());
 _FUNCTION(__uint load_task, (__ptask ptask));
 _FUNCTION(void schedule, ()); 
