@@ -12,9 +12,27 @@
 #include <linuxmt/types.h>
 #include <linuxmt/sched.h>
 
-__pregisters CURRENT, NEXT;
+/* This is used by the asm files */ 
 
-/* Bad hack - should be moved/pulled before 0.00.2ab */
+__ptask CURRENT, NEXT;
+
+void schedule_task()
+{
+    while (1) {
+	save_regs(NEXT);
+	NEXT = &task[2];
+	load_regs(NEXT);
+	schedule();
+	save_regs(NEXT);
+	NEXT = &task[0];
+	load_regs(NEXT);
+	schedule();
+	save_regs(NEXT);
+	NEXT = &task[3];
+	load_regs(NEXT);
+	schedule();
+    };
+}
 
 __uint build_task()
 {
